OC.L10N.register(
    "bookmarks",
    {
    "Bookmarks" : "Favoritos",
    "Failed to import one bookmark, because: " : "Falha ao importar os favoritos, porque: ",
    "No file provided for import" : "Nenhum arquivo para importar",
    "Unsupported file type for import" : "O tipo de arquivo não é suportado",
    "Add a Bookmark" : "Adicionar um marcador",
    "Add folder" : "Adicionar pasta",
    "Select" : "Selecionar",
    "Deselect" : "Desselecionar",
    "Details" : "Detalhes",
    "Delete" : "Excluir",
    "Saved" : "Salvo",
    "Tags" : "Etiquetas",
    "Description" : "Descrição",
    "No bookmarks here." : "Não há marcadores aqui.",
    "Favorites" : "Favoritos",
    "Settings" : "Configurações",
    "Bookmarklet" : "Bookmarklet",
    "Add to {instanceName} " : "Adicionar a {instanceName} ",
    "Recently added" : "Adicionados recentemente",
    "Most visited" : "Mais visitados",
    "RSS Feed" : "Feed RSS",
    "Permanently remove all bookmarks from your account. There is no going back!" : "Remover permanentemente todos os favoritos. Não há como desfazer isso!",
    "Delete all bookmarks" : "Excluir todos os favoritos",
    "Open details" : "Abrir detalhes",
    "An error occurred while trying to save the bookmark." : "Um erro ocorreu enquanto tentava salvar o favorito.",
    "Error" : "Erro",
    "Uncategorized" : "Não categorizado",
    "Import error" : "Erro na importação",
    "Import completed successfully." : "Importação finalizada com sucesso.",
    "Set tags" : "Atribuir tags",
    "A Bookmark manager for Nextcloud" : "Um gerenciador de marcadores para o Nextcloud",
    "This app allows you to store and organize your favorite places on the web in one spot, while allowing you to sync them with your various devices and browsers.\nCheck out the third-party clients listed here: https://github.com/nextcloud/bookmarks#third-party-clients" : "Este aplicativo permite que você armazene e organize seus lugares favoritos na Web em um único local, ao mesmo tempo em que permite sincronizá-los com vários dispositivos e navegadores.\nConfira os clientes de terceiros listados aqui: https://github.com/nextcloud/bookmarks#third-party-clients",
    "Add a bookmark" : "Adicionar um favorito",
    "This URL is already bookmarked! Overwrite?" : "Esta URL já está como favorito. Sobrescrever?",
    "The title of the page" : "O título da página",
    "The address of the page" : "O endereço da página",
    "Description of the page" : "Descrição da página",
    "Save" : "Salvar",
    "Previews" : "Prévias",
    "In order to display real screenshots of your bookmarked websites, Bookmarks can use a third-party service to generate those." : "Para exibir capturas de tela de seus sites favoritos, os Favoritos podem usar um serviço de terceiros para gerá-las.",
    "You can either sign up for free at <a href=\"http://screeenly.com\">screeenly.com</a> or <a href=\"https://github.com/stefanzweifel/screeenly\">setup your own server</a>." : "Você pode inscrever-se gratuitamente em <a href=\"https://screeenly.com\">http://screeenly.com</a> ou <a href=\"https://github.com/stefanzweifel/screeenly\">criar seu próprio servidor</a>.",
    "Screenly API URL" : "URL da API Screenly",
    "Screenly API key" : "Chave da API Screenly",
    "Bookmarks feed" : "Feed de favoritos"
},
"nplurals=2; plural=(n > 1);");
